@@ -3,7 +3,7 @@ from pandas import DataFrame as PandasDF
 
 import numpy as np
 from functools import reduce
-from pyspark.sql.types import LongType
+from pyspark.sql.types import LongType, StringType
 from pyspark.sql import functions as f
 import hashlib
 import base64
@@ -30,6 +30,12 @@ def concat_spark_columns(data, name='concat_column', sep='|', return_data=False)
 	:param return_data: if True, the whole data frome with the new column is returned, otherwise just the column
 	:rtype: SparkDF
 	"""
+	data = data.select(
+		*[
+			f.col(col).cast(StringType()).alias(col)
+			for col in data.columns
+		]
+	)
 	data = data.withColumn(
 		name, f.concat_ws(
 			sep, *[f.col(col) for col in data.columns]
